@@ -117,12 +117,9 @@ class ContractVerifier:
         )
 
     def verify_deployment_data(self, deployment_data: DeployedContracts) -> bool:
-        chain_id = self.web3.eth.chain_id
 
         if self.contract_manager.contracts_version != deployment_data["contracts_version"]:
             raise RuntimeError("Version string mismatch.")
-        if chain_id != deployment_data["chain_id"]:
-            raise RuntimeError("chain id mismatch.")
 
         secret_registry, _ = self._verify_deployed_contract(
             deployment_data=deployment_data, contract_name=CONTRACT_SECRET_REGISTRY
@@ -138,7 +135,7 @@ class ContractVerifier:
             != secret_registry.address
         ):
             raise RuntimeError("secret_registry_address onchain has an unexpected value.")
-        if len(constructor_arguments) != 5:
+        if len(constructor_arguments) != 4:
             raise RuntimeError(
                 "TokenNetworkRegistry received a wrong number of constructor arguments."
             )
@@ -146,15 +143,13 @@ class ContractVerifier:
             raise RuntimeError(
                 "TokenNetworkRegistry's constructor received a different SecretRegistry address."
             )
-        if token_network_registry.functions.chain_id().call() != constructor_arguments[1]:
-            raise RuntimeError("TokenNetwork remembers a wrong chain_id.")
         assert (
             token_network_registry.functions.settlement_timeout_min().call()
-            == constructor_arguments[2]
+            == constructor_arguments[1]
         )
         assert (
             token_network_registry.functions.settlement_timeout_max().call()
-            == constructor_arguments[3]
+            == constructor_arguments[2]
         )
 
         return True
