@@ -41,7 +41,7 @@ def test_settle_no_bp_success(
     get_accounts: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ The simplest settlement without any balance proofs provided """
+    """The simplest settlement without any balance proofs provided"""
     (A, B) = get_accounts(2)
     deposit_A = 10
     deposit_B = 6
@@ -97,7 +97,7 @@ def test_settle2_no_bp_success(
     get_accounts: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ The simplest settlement, tested against the V2 ABI settle """
+    """The simplest settlement, tested against the V2 ABI settle"""
     (A, B) = get_accounts(2)
     deposit_A = 10
     deposit_B = 6
@@ -159,7 +159,7 @@ def test_settle_channel_state(
     close_and_update_channel: Callable,
     settle_state_tests: Callable,
 ) -> None:
-    """ settleChannel() with some balance proofs """
+    """settleChannel() with some balance proofs"""
     (A, B) = get_accounts(2)
     vals_A = ChannelValues(
         deposit=40,
@@ -413,7 +413,7 @@ def test_settlement_with_unauthorized_token_transfer(
     withdraw_channel: Callable,
     close_and_update_channel: Callable,
 ) -> None:
-    """ A participant transfers some tokens to the contract and so loses them """
+    """A participant transfers some tokens to the contract and so loses them"""
     externally_transferred_amount = 5
     (A, B) = get_accounts(2)
     (vals_A, vals_B) = (
@@ -486,7 +486,7 @@ def test_settle_wrong_state_fail(
     get_block: Callable,
     create_close_signature_for_no_balance_proof: Callable,
 ) -> None:
-    """ settleChannel() fails on OPENED state and on CLOSED state before the settlement block """
+    """settleChannel() fails on OPENED state and on CLOSED state before the settlement block"""
     (A, B) = get_accounts(2)
     vals_A = ChannelValues(deposit=35)
     vals_B = ChannelValues(deposit=40)
@@ -498,7 +498,7 @@ def test_settle_wrong_state_fail(
     assert state == ChannelState.OPENED
     assert settle_timeout == TEST_SETTLE_TIMEOUT_MIN
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: channel not closed"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
 
     closing_sig = create_close_signature_for_no_balance_proof(A, channel_identifier)
@@ -523,7 +523,7 @@ def test_settle_wrong_state_fail(
     assert settle_block_number == TEST_SETTLE_TIMEOUT_MIN + get_block(txn_hash)
     assert web3.eth.block_number < settle_block_number
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: settlement timeout"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
 
     mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
@@ -547,7 +547,7 @@ def test_settle_wrong_balance_hash(
     close_and_update_channel: Callable,
     reveal_secrets: Callable,
 ) -> None:
-    """ Calling settleChannel() with various wrong arguments and see failures """
+    """Calling settleChannel() with various wrong arguments and see failures"""
     (A, B) = get_accounts(2)
     vals_A = ChannelValues(
         deposit=35,
@@ -587,61 +587,61 @@ def test_settle_wrong_balance_hash(
 
     mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
 
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, B, vals_A, A, vals_B)
 
     vals_A_fail = deepcopy(vals_A)
     vals_A_fail.transferred += 1
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, A, vals_A_fail, B, vals_B)
 
     vals_A_fail.transferred = 0
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, A, vals_A_fail, B, vals_B)
 
     vals_A_fail.transferred = UINT256_MAX
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, B, vals_B, A, vals_A_fail)
 
     vals_A_fail = deepcopy(vals_A)
     vals_A_fail.locked_amounts.claimable_locked += 1
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, A, vals_A_fail, B, vals_B)
 
     vals_A_fail.locked_amounts.claimable_locked = 0
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, A, vals_A_fail, B, vals_B)
 
     vals_A_fail.locked_amounts.unclaimable_locked = 0
     vals_A_fail.locked_amounts.claimable_locked = UINT256_MAX
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, B, vals_B, A, vals_A_fail)
 
     vals_A_fail = deepcopy(vals_A)
     vals_A_fail.locksroot = LOCKSROOT_OF_NO_LOCKS
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, A, vals_A_fail, B, vals_B)
 
     vals_A_fail.locksroot = fake_bytes(32, "01")
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, A, vals_A_fail, B, vals_B)
 
     vals_B_fail = deepcopy(vals_B)
     vals_B_fail.transferred += 1
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B_fail)
 
     vals_B_fail.transferred = 0
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 1"):
         call_settle(token_network, channel_identifier, B, vals_B_fail, A, vals_A)
 
     vals_B_fail.transferred = UINT256_MAX
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B_fail)
 
     vals_B_fail = deepcopy(vals_B)
     vals_B_fail.locked_amounts.claimable_locked += 1
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B_fail)
 
     vals_B_fail.locked_amounts.claimable_locked = 0
@@ -650,16 +650,16 @@ def test_settle_wrong_balance_hash(
 
     vals_B_fail.locked_amounts.unclaimable_locked = 0
     vals_B_fail.locked_amounts.claimable_locked = UINT256_MAX
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B_fail)
 
     vals_B_fail = deepcopy(vals_B)
     vals_B_fail.locksroot = LOCKSROOT_OF_NO_LOCKS
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B_fail)
 
     vals_B_fail.locksroot = fake_bytes(32, "01")
-    with pytest.raises(TransactionFailed):
+    with pytest.raises(TransactionFailed, match="TN/settle: invalid data for participant 2"):
         call_settle(token_network, channel_identifier, A, vals_A, B, vals_B_fail)
 
     # Channel is settled
@@ -676,7 +676,7 @@ def test_settle_channel_event(
     create_balance_proof_countersignature: Callable,
     event_handler: Callable,
 ) -> None:
-    """ A successful settleChannel() call causes a SETTLED event """
+    """A successful settleChannel() call causes a SETTLED event"""
     ev_handler = event_handler(token_network)
     (A, B) = get_accounts(2)
     deposit_A = 10
@@ -733,5 +733,11 @@ def test_settle_channel_event(
         {"from": A},
     )
 
-    ev_handler.add(txn_hash, ChannelEvent.SETTLED, check_channel_settled(channel_identifier, 5, 5))
+    ev_handler.add(
+        txn_hash,
+        ChannelEvent.SETTLED,
+        check_channel_settled(
+            channel_identifier, B, 5, LOCKSROOT_OF_NO_LOCKS, A, 5, LOCKSROOT_OF_NO_LOCKS
+        ),
+    )
     ev_handler.check()
